.. module:: enaml.widgets.check_box

=======================
enaml.widgets.check_box
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    CheckBox


.. autoclass:: CheckBox
